<style>
    .nav {
        margin: 5px auto;
    }

    .part_lock {
        filter: alpha(Opacity=80);
        -moz-opacity: 0.1;
        opacity: 0.2;
    }

    {#===section1列表，全部课程列表===#}
    .section_list1 .user_section_list {
    }

    .section_list1 .user_section {
        margin: 15px auto;

    }



    .section_list1 .section_group_name {
        font-size: 1.5em;
    }

    .section_list1 .section_title {
        font-weight: 900;
    }

    .section_list1 .part_title {

    }

    {#===section2列表，预备课列表===#}
    .section_list2 .section_group_name {
        font-size: 1.5em;
    }

    .section_list2 .section_title {
        margin: 15px auto;
    }

    .section_list2 .user_part {
        margin: 5px auto;
    }
    .section_list2 .user_part img {
        width: 90%;
        max-width: 300px;

    }

    {#===detail1详情，课件详情===#}

    .section_detail .user_part_list {
    }

    .section_detail .user_part {
        margin: 5px auto;
    }

    .section_detail .user_part_image img {
        width: 90%;
        max-width: 300px;

    }

    .section_detail .user_part_image_text {
        margin: 10px auto;
    }

    {#===part详情，小节详情===#}

    .part_detail .user_questions {
    }

    .part_detail .question_res {
        margin: 5px auto;
        color: red;
    }

    .part_detail .unselectable {

    }

    .part_detail .user_videos {

    }
</style>